@@ -57,6 +57,18 @@ class ADCDevice:
             logger.error('could not read ADC value {}'.format(e))
             self._adc.ADS1263_Exit()
 
+    def read_fast(self):
+        try:
+            adc_value = self._adc.ADS1263_GetChannalValue(ADC_CHANNEL)
+            if adc_value >> 31 == 1:
+                value = REF * 2 - adc_value * REF / 0x80000000
+            else:
+                value = adc_value * REF / 0x7fffffff  # 32bit
+            return value
+        except Exception as e:
+            logger.error('could not read ADC value {}'.format(e))
+            self._adc.ADS1263_Exit()
+
 
 class MockADCDevice:
 
@@ -119,7 +131,7 @@ class ScanCommand:
                         currentY = self._controller.extVcm.get_angle_y()
                         activeCavity = self._controller.get_active_cavity_index()
 
-                        detectorVoltage = self._controller.adc.read()
+                        detectorVoltage = self._controller.adc.read_fast()
                         self.results['active_cavity'].append(activeCavity)
                         self.results['x_set_point'].append(posX)
                         self.results['x'].append(currentX)
@@ -204,7 +216,7 @@ class FastScanCommand:
             if self.stopped.is_set():
                 return
             with self._acqLockDetector:
-                self._detectorAcquisitions.append((time.time(), self._controller.adc.read()))
+                self._detectorAcquisitions.append((time.time(), self._controller.adc.read_fast()))
             if self.stopped.wait(0.001):
                 return
 
@@ -264,11 +276,13 @@ class FastScanCommand:
                     activeCavity = self._controller.get_active_cavity_index()
                     self.results['active_cavity'].append(activeCavity)
 
-                    self.results['x'].append(interpX.tolist())
-                    self.results['y'].append(interpY.tolist())
-                    self.results['wavelength_set_point'].append(wavelength)
-                    self.results['wavelength'].append(cavity.get_wavelength())
-                    self.results['detector_voltage'].append(detectorValues.tolist())
+                    measured_wl = cavity.get_wavelength()
+
+                    self.results['x'].extend(interpX.tolist())
+                    self.results['y'].extend(interpY.tolist())
+                    self.results['wavelength_set_point'].extend(len(interpX.tolist())*[wavelength])
+                    self.results['wavelength'].extend(len(interpX.tolist())*[measured_wl])
+                    self.results['detector_voltage'].extend(detectorValues.tolist())
 
                     self.activeCavity = activeCavity
                     self.currentX = None
