@@ -290,7 +290,7 @@ class VCMirror:
                     self._position_y = pos_angle_y
                     self._temperature = self.device.TemperatureManager.GetProxyTemperature()[0]
                     self._last_recording = time.time()
-                    self.record_callback(pos_x_cal, pos_y_cal, self._last_recording)
+                    self.record_callback(pos_angle, pos_angle_y, self._last_recording)
             except Exception as e:
                 logger.exception(e)
                 logger.info('error communicating with VCM')
@@ -369,25 +369,40 @@ class VCMirror:
 
     def start_x_signal_generator(self, amplitude, frequency, offset, shape):
         with self.data_lock:
-            self.device.Mirror.Channel_0.SignalGenerator.SetAmplitude(amplitude)
-            self.device.Mirror.Channel_0.SignalGenerator.SetFrequency(frequency)
-            self.device.Mirror.Channel_0.SignalGenerator.SetAsInput()
-            self.device.Mirror.Channel_0.SignalGenerator.SetUnit(2)
-            self.device.Mirror.Channel_0.SignalGenerator.SetShape(shape)
-            self.device.Mirror.Channel_0.SignalGenerator.SetCycles(-1)
-            self.device.Mirror.Channel_0.SignalGenerator.SetOffset(offset)
-            self.device.Mirror.Channel_0.SignalGenerator.Run()
+            amp = convert_angles_deg_to_position_x(amplitude)
+            off = convert_angles_deg_to_position_x(offset)
+            max_position = abs(amplitude) + abs(offset)
+            valid =  self.angle_not_out_of_bounds(max_position)
+
+            if valid:
+                self.device.Mirror.Channel_0.SignalGenerator.SetAmplitude(amp)
+                self.device.Mirror.Channel_0.SignalGenerator.SetFrequency(frequency)
+                self.device.Mirror.Channel_0.SignalGenerator.SetAsInput()
+                self.device.Mirror.Channel_0.SignalGenerator.SetUnit(2)
+                self.device.Mirror.Channel_0.SignalGenerator.SetShape(shape)
+                self.device.Mirror.Channel_0.SignalGenerator.SetCycles(-1)
+                self.device.Mirror.Channel_0.SignalGenerator.SetOffset(off)
+                self.device.Mirror.Channel_0.SignalGenerator.Run()
+            else:
+                raise OutOfRangeError
 
     def start_y_signal_generator(self, amplitude, frequency, offset, shape):
         with self.data_lock:
-            self.device.Mirror.Channel_1.SignalGenerator.SetAmplitude(amplitude)
-            self.device.Mirror.Channel_1.SignalGenerator.SetFrequency(frequency)
-            self.device.Mirror.Channel_1.SignalGenerator.SetAsInput()
-            self.device.Mirror.Channel_1.SignalGenerator.SetUnit(2)
-            self.device.Mirror.Channel_1.SignalGenerator.SetShape(shape)
-            self.device.Mirror.Channel_1.SignalGenerator.SetCycles(-1)
-            self.device.Mirror.Channel_1.SignalGenerator.SetOffset(offset)
-            self.device.Mirror.Channel_1.SignalGenerator.Run()
+            amp = convert_angles_deg_to_position_x(amplitude)
+            off = convert_angles_deg_to_position_x(offset)
+            max_position = abs(amplitude) + abs(offset)
+            valid =  self.angle_not_out_of_bounds(max_position)
+            if valid:
+                self.device.Mirror.Channel_1.SignalGenerator.SetAmplitude(amp)
+                self.device.Mirror.Channel_1.SignalGenerator.SetFrequency(frequency)
+                self.device.Mirror.Channel_1.SignalGenerator.SetAsInput()
+                self.device.Mirror.Channel_1.SignalGenerator.SetUnit(2)
+                self.device.Mirror.Channel_1.SignalGenerator.SetShape(shape)
+                self.device.Mirror.Channel_1.SignalGenerator.SetCycles(-1)
+                self.device.Mirror.Channel_1.SignalGenerator.SetOffset(off)
+                self.device.Mirror.Channel_1.SignalGenerator.Run()
+            else:
+                raise OutOfRangeError
 
     def reset_static_input(self):
         with self.data_lock:
