@@ -28,6 +28,8 @@ def scan():
     parser = ArgumentParser()
     parser.add_argument('-x', nargs='+', type=float)
     parser.add_argument('-y', nargs='+', type=float)
+    parser.add_argument('-ampl_x', type=float, default=5)
+    parser.add_argument('-ampl_y', type=float, default=5)
     parser.add_argument('-wl_step', type=float, required=False, default=WL_INCREMENT)
     parser.add_argument('-scan', type=str, choices=['default', 'fast'], required=True)
     parser.add_argument('-url', type=str, required=False, default=PHOOTONICS_URL)
@@ -54,7 +56,9 @@ def scan():
             rsp.raise_for_status()
     elif args.scan == 'fast':
         rsp = requests.post(args.url + '/scan/start/fast',
-                            json={'wl_step': args.wl_step})
+                            json={'wl_step': args.wl_step,
+                                  'amplitude_x': args.ampl_x,
+                                  'amplitude_y': args.ampl_y})
         if not rsp.status_code == 200:
             print(rsp.json())
             rsp.raise_for_status()
